pub fn build_graph_batch(nodes: &[CommitNode]) -> Result<RecordBatch>Expand description
Serialize the commit graph to a single Arrow record batch.
pub fn build_graph_batch(nodes: &[CommitNode]) -> Result<RecordBatch>Serialize the commit graph to a single Arrow record batch.