pub trait BaseSource {
// Required method
fn content(&self, oid: &[u8]) -> Option<(GitObjectKind, Vec<u8>)>;
}Expand description
Where an entry that deltas against something outside the pack gets its base.
Implemented by the store, which may or may not be able to answer — see the module docs on 14.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".